#!/usr/bin/perl -I/usr/sausalito/perl -I/usr/sausalito/handlers/base/vsite
# $Id: user_symlinkfix.pl
#
# This checks if /home/sites/<fqdn>/users/<username> exists and if it's a
# symlink to the real users home directory. If the symlink is missing, it
# will recreate it automatically.
#

use CCE;
my $cce = new CCE;
use File::Path;
use Sauce::Util;
use Base::HomeDir qw(
        homedir_get_user_dir homedir_create_user_link
        homedir_setup_admin_home homedir_setup_user_home);
use Base::User qw(system_useradd useradd usermod);

$cce->connectuds();

# Root check:
my $id = `id -u`;
chomp($id);
if ($id ne "0") {
    print "$0 must be run by user 'root'!\n";

    $cce->bye('FAIL');
    exit(1);
}

# Find all Vsites:
my @vhosts = ();
my (@vhosts) = $cce->findx('Vsite');

# Walk through all Vsites:
for my $vsite (@vhosts) {
    ($ok, my $my_vsite) = $cce->get($vsite);

    print "Checking Site $my_vsite->{fqdn}\n";

    # Start with an empty and predefined array:
    my @users = ();
    
    # Get all users of this Vsite:
    @users = $cce->findx('User', { 'site' => $my_vsite->{name} });

    # Walk through all users of that Vsite:
    for my $user (@users) {

        # Get the username:
        ($ok, my $myuser) = $cce->get($user);

        $Vsite_Basedir = $my_vsite->{'basedir'};

        my $homedir = '';
        $homedir = homedir_get_user_dir($myuser->{name}, $myuser->{site}, $myuser->{volume});

        $LinkPath = '/home/sites/' . $my_vsite->{fqdn} . '/users/' . $myuser->{name};
        if (! -l $LinkPath) {
            print "Symlink $LinkPath is missing! Creating it!\n";
            my ($dir_link, $link_target) = homedir_create_user_link($myuser->{name}, $myuser->{site}, $myuser->{volume});
            Sauce::Util::linkfile($link_target, $dir_link);
        }
    }
}

$cce->bye('SUCCESS');
exit(0);

# 
# Copyright (c) 2019 Michael Stauber, SOLARSPEED.NET
# Copyright (c) 2019 Team BlueOnyx, BLUEONYX.IT
# All Rights Reserved.
# 
# 1. Redistributions of source code must retain the above copyright 
#     notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright 
#     notice, this list of conditions and the following disclaimer in 
#     the documentation and/or other materials provided with the 
#     distribution.
# 
# 3. Neither the name of the copyright holder nor the names of its 
#     contributors may be used to endorse or promote products derived 
#     from this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.
# 
# You acknowledge that this software is not designed or intended for 
# use in the design, construction, operation or maintenance of any 
# nuclear facility.
# 